Struct amazon_sp_fba_small_and_light::models::small_and_light_eligibility::SmallAndLightEligibility
source · [−]pub struct SmallAndLightEligibility {
pub marketplace_id: String,
pub seller_sku: String,
pub status: SmallAndLightEligibilityStatus,
}Expand description
SmallAndLightEligibility : The Small and Light eligibility status of the item indicated by the specified seller SKU.
Fields
marketplace_id: StringA marketplace identifier.
seller_sku: StringIdentifies an item in the given marketplace. SellerSKU is qualified by the seller’s SellerId, which is included with every operation that you submit.
status: SmallAndLightEligibilityStatusImplementations
sourceimpl SmallAndLightEligibility
impl SmallAndLightEligibility
sourcepub fn new(
marketplace_id: String,
seller_sku: String,
status: SmallAndLightEligibilityStatus
) -> SmallAndLightEligibility
pub fn new(
marketplace_id: String,
seller_sku: String,
status: SmallAndLightEligibilityStatus
) -> SmallAndLightEligibility
The Small and Light eligibility status of the item indicated by the specified seller SKU.